/*preparation data set
************************
clear all
set more off
*use "G:\Documents\Documents\data JVB (1)\Data set Inge\Prep_SIM.dta", clear
use "G:\Paper_men's postdivorce fertility\birtyreaspartners.dta", clear
rename AX99904 IDpartner
save "G:\Paper_men's postdivorce fertility\birthdate_partner.dta", replace

use "G:\Paper_men's postdivorce fertility\educpart.dta", clear
rename AX99904 IDpartner
rename AR99916 edupart
keep IDpartner edupart
save "G:\Paper_men's postdivorce fertility\educpartner.dta", replace

use "G:\Documents\Documents\data JVB (1)\Data set Inge\Prep_SIM.dta", clear

browse ///
/*individual background*/ IDpartner REL  EDU BIRTH_YR SEX CURR_AGE ///
	/*first marriage background*/ COHORT SEP_YR DIV_YR N_KIDS_DIV AGEYSTKID_DIV AGE_MARDIS ///
	/*general time-varying information*/ START END ///
	/*household formation process information*/ START1 END1 EVENT1 BASE1 ORD ///
	/*post-marital childbearing information*/ START2 END2 EVENT2 EVENT2b BASE2 PMKIDS ///
	/*control covariates in both processes*/ UNION CUSTODY CUSTODY_cat CURAGE_YGKID NoAge_Kids apinhoudtv_MV aantalinwkindtv ///
	/*control covariates household formation*/  CONCEP PMCONCS /// 
	/*control covariates childbearing*/  COHAB MARR  PARTNERKIDS 

merge m:1 IDpartner using "G:\Paper_men's postdivorce fertility\birthdate_partner.dta" 

drop if _merge==2
drop _merge

merge m:1 IDpartner using "G:\Paper_men's postdivorce fertility\educpartner.dta" 

drop if _merge==2
drop _merge

sample 20 if START==0
	sort IDpartner
	by IDpartner: egen MIN=min(START)
	drop if MIN==1
	drop MIN

save "G:\Paper_men's postdivorce fertility\3529.dta", replace */

************************************************************************
use "G:\Paper_men's postdivorce fertility\3529.dta", clear

*SAMPLE SELECTION
	
*drop women
	drop if SEX==1
	
*in a partnership at time of interview?
	sort IDpartner START
	by IDpartner: g NEU_n=_n
	by IDpartner: g NEU_N=_N
	
	g partint=UNION if NEU_n==NEU_N
	by IDpartner: egen PART_INT=min(partint)
	
	tab PART_INT edupart, m
	drop if PART_INT==0 & edupart!=.

*restrict time frame to first 7 years completely observed
	drop if END>84

	sort IDpartner
	by IDpartner: egen MAXEND=max(END)
	drop if MAXEND<84
	
	count if START==0
	*1382 men

*drop if education is missing
	drop if EDU==99


*drop if parental status of new partner is missing
*replace PARTNERKIDS=0 if PARTNERKIDS==99 & UNION==0
	replace PARTNERKIDS=88 if PARTNERKIDS==99 & UNION==0 & COHAB==0
	replace PARTNERKIDS=88 if UNION==0 & COHAB==0
	sort IDpartner ORD
	by IDpartner /*ORD*/: egen PKID=max(PARTNERKIDS)
	lab val PKID PARTNERKIDS

	drop if PKID==99
*drops 20% of the men. If we only include the partnerless episodes we would underestimate repartnering. 



*NEW VARIABLES
*****************************

*label edu
	lab def EDU 1 "low educated" 2 "medium educated" 3 "highly educated"
	lab val EDU EDU
*edu partner
	lab val edupart EDU
	replace edupart=99 if edupart==.

*binary variable for residential children
	g RES=0
	replace RES=1 if aantalinwkindtv!=0

*binary variable for children
	g KIDS=0
	replace KIDS=1 if N_KIDS_DIV!=0
	sort IDpartner START
	replace RES=0 if KIDS==0 &  RES==1 
	replace RES=0 if RES==1 & RES[_n+1]==0 & START==0
	
*age and number of children, 2 age categories: 
	g NKIDS=0
	replace NKIDS=1 if NoAge_Kids==1
	replace NKIDS=2 if NoAge_Kids==2 | NoAge_Kids==3
	replace NKIDS=3 if NoAge_Kids==4 | NoAge_Kids==5
	replace NKIDS=4 if NoAge_Kids==6 

* age and number of children, 2 age categories
	g NoAge_Kids2=0
	replace NoAge_Kids2=1 if N_KIDS_DIV==1 & AGEYSTKID_DIV<=8
	replace NoAge_Kids2=2 if N_KIDS_DIV==1 & AGEYSTKID_DIV>8
	replace NoAge_Kids2=3 if N_KIDS_DIV>1 & AGEYSTKID_DIV<=8
	replace NoAge_Kids2=4 if N_KIDS_DIV>1 & AGEYSTKID_DIV>8
	lab def NoAge_Kids2 0 "no kids" 1 "one child, up to age 8" 2 "one child, older than 8" 3 "2+ children, ygst up to age 8" 4 "2+ children, older than 8"
	lab val NoAge_Kids2 NoAge_Kids2

*divorce cohort (5 year intervals)	
	g DIV_YR5=1 if DIV_YR>=1981 & DIV_YR<1985
	replace DIV_YR5=2 if DIV_YR>=1985 & DIV_YR<1990
	replace DIV_YR5=3 if DIV_YR>=1990 & DIV_YR<1996
	replace DIV_YR5=4 if DIV_YR>=1996 & DIV_YR<2001
	replace DIV_YR5=5 if DIV_YR>=2001 & DIV_YR<2006

	lab def DIV_YR5 1 "1981-1984" 2 "1985-1989" 3 "1990-1995" 4 "1996-2000" 5 "2001-2005"
	lab val DIV_YR5 DIV_YR5
	
	
*Post-divorce children in total (tc)
	sort IDpartner ORD
	by IDpartner ORD: egen PM_FERT=max(PMKIDS)
	g FERT=0
	replace FERT=1 if PM_FERT!=0
	
*partner's kids
	sort IDpartner START
	g PK=0
	replace PK=1 if PARTNERKIDS==0 & COHAB==1
	replace PK=2 if PARTNERKIDS==1 & COHAB==1
	sort IDpartner ORD
	by IDpartner ORD: egen PARTK=max(PK)
	lab def PARTK 0 "no partner"  1 "childless partner" 2 "mother" 
	lab val PARTK PARTK
	
*age at divorce, categorical
	g AGE_MARD=0
	replace AGE_MARD=1 if AGE_MARDIS>=30 & AGE_MARDIS<35
	replace AGE_MARD=2 if AGE_MARDIS>=35 & AGE_MARDIS<40
	replace AGE_MARD=3 if AGE_MARDIS>=40 & AGE_MARDIS<45
	replace AGE_MARD=4 if AGE_MARDIS>=45 
	lab def AGE_MARD 0 "<30" 1 "30-34" 2 "35-39" 3 "40-44" 4 "45+" 5 "50+"
	lab val AGE_MARD AGE_MARD
	
*age at union formation
	sort IDpartner START
	g age=.
	replace age=CURR_AGE if COHAB==1 & COHAB[_n-1]==0
	replace age=CURR_AGE if COHAB==1 & START==0
	sort IDpartner ORD
	by IDpartner ORD: egen AGE=min(age)
	replace AGE=99 if AGE==.
	
**age at union formation, categorical
	g AGE_U=0
	replace AGE_U=1 if AGE>=30 & AGE<35
	replace AGE_U=2 if AGE>=35 & AGE<40
	replace AGE_U=3 if AGE>=40 & AGE<45
	replace AGE_U=4 if AGE>=45 
	replace AGE_U=99 if AGE==99
	lab def AGE_U 0 "<30" 1 "30-34" 2 "35-39" 3 "40-44" 4 "45+"  99 "missing" 
	lab val AGE_U AGE_U
	
*partner's age at union formation
	sort IDpartner START
	g agep=.
	replace agep=(CURR_AGE+BIRTH_YR)-birthyea if birthyea!=. & COHAB==1 & COHAB[_n-1]==0
	replace agep=(CURR_AGE+BIRTH_YR)-birthye0 if agep==. & birthye0!=. & COHAB==1 & COHAB[_n-1]==0
	replace agep=(CURR_AGE+BIRTH_YR)-birthye1 if agep==. & birthye1!=. & COHAB==1 & COHAB[_n-1]==0
	replace agep=(CURR_AGE+BIRTH_YR)-birthyea if birthyea!=. & START==0 & COHAB==1 & agep==.
	sort IDpartner ORD
	by IDpartner ORD: egen AGE_P=min(agep)
	replace AGE_P=99 if AGE_P==.
	*drop agep
	
	*impute missings
	g AGE_PP=AGE_P
	sort IDpartner ORD
	count if AGE_PP==99 & AGE_U!=99 & START==0
	by IDpartner ORD: replace AGE_PP=AGE if AGE_PP==99 & AGE_U!=99
	
	*impute inconsistencies
	count if AGE_PP<18 & START==0
	by IDpartner ORD: replace AGE_PP=AGE if AGE_PP<18
	
**partner's age at union formation, categorical
	g AGE_UP=0
	replace AGE_UP=1 if AGE_PP>=30 & AGE_PP<35
	replace AGE_UP=2 if AGE_PP>=35 & AGE_PP<40
	replace AGE_UP=3 if AGE_PP>=40 
	replace AGE_UP=99 if AGE_PP==99
		lab def AGE_UP 0 "<30" 1 "30-34" 2 "35-39" 3 "40+"  99 "missing"
	lab val AGE_UP AGE_UP
	
	g PARTNERKIDS2=PARTNERKIDS
	sort IDpartner ORD
	by IDpartner ORD: replace PARTNERKIDS2=runiformint(0,1) if PARTNERKIDS==99

*generate element variable
***********************************
	 
*lives alone with children as additional category:
g st9=0
*childless men
	replace st9=1 if KIDS==0 & COHAB==0
	* non-res father
	replace st9=2 if RES==0 & KIDS==1 & COHAB==0
	*res father
	replace st9=3 if RES!=0 & KIDS==1 & COHAB==0
	*childless couple
	replace st9=4 if COHAB==1 & RES==0 & PARTNERKIDS==0 & PMCONCS==0
	*nuclear family
	replace st9=5 if COHAB==1 & RES==0 & PARTNERKIDS==0 & PMCONCS!=0
	*stepmother family
	replace st9=6 if COHAB==1 & RES!=0 & PARTNERKIDS==0 & PMCONCS==0
	*stepmother&child 
	replace st9=7 if COHAB==1 & RES!=0 & PARTNERKIDS==0 & PMCONCS!=0
	*stepfather family
	replace st9=8 if COHAB==1 & RES==0 & PARTNERKIDS==1 & PMCONCS==0
	*stepfather& child
	replace st9=9 if COHAB==1 & RES==0 & PARTNERKIDS==1 & PMCONCS!=0
	*stepparents family
	replace st9=10 if COHAB==1 & RES!=0 & PARTNERKIDS==1 & PMCONCS==0
	*stepparents&child
	replace st9=11 if COHAB==1 & RES!=0 & PARTNERKIDS==1 & PMCONCS!=0
	*replace st9=12 if PARTNERKIDS==99 & RES==0
	*replace st9=13 if PARTNERKIDS==99 & RES==1
	lab def st9 0 "else" 1 " single&childless" 2 "single&non-res children" 3 "single& res children" 4 "childless couple" 5 "nuclear family" ///
	6 " step-mother family" 8 " step-father family" 10 "step-parents family" ///
	7 " step-mother family & child" 9 " step-father family & child" 11 "step-parents family & child" 12 "rep men w/o res children, partner's parental status unknown" 13 "rep res father, partners parental status unknown"
	 lab val st9 st9


*roles of parenthood
	g role=0
	*bio childless
	replace role=1 if st9==1 | st9==4
	*non res father
	replace role=2 if RES==0 & KIDS==1
	*bio father
	replace role=3 if st9==3 | st9==5 | st9==6 | st9==7
	*stepfather
	replace role=4 if st9==8
	*step&bio father
	replace role=5 if st9==10 | st9==9 | st9==11
	replace role=6 if PARTNERKIDS==99
	lab def role 1 "biol. childless" 2 "no res father role" 3 "biological father" 4 "stepfather" 5 "step&bio father"
	lab val role role


	sort IDpartner
	by IDpartner: egen ROLE=max(role)
	by IDpartner: egen ST9=max(st9)
	lab val ST9 st9
	lab val ROLE role

*no child, no separation  separation  common child
	g sep=0
	replace sep=1 if ORD==2
	replace sep=2 if PMKIDS!=0 
	by IDpartner: egen SEP=max(sep)
	lab def SEP 0 "no child/in union" 1 "separation" 2 "common child" 
	lab val SEP SEP

*g marital status (married if before childbirth)
	g mar=0
	replace mar=1 if MARR==1 & CONCEP==0
	by IDpartner: egen marstat=max(mar)
	lab def marstat 0 "not married/marr after conception" 1 "married before ev conception"
	lab val marstat marstat

*g marital status (married before or after childbirth)
	g mar2=0
	replace mar2=1 if MARR==1 & CONCEP==1
	by IDpartner: egen marstat2=max(mar2)
	g mar3=0
	replace mar3=2 if marstat2==1
	replace mar3=1 if marstat==1

	tab mar3 if START==0 & PARTK!=0

	label def EDU 1 "low" 2 "medium" 3 "high", replace
	label val EDU EDU
	lab var EDU "Man's education"


 *DESCRIPTIVES
******************************

*TABLE 2

tab EDU if START==0

*sample composition: all divorced men
mean AGE_MARDIS if EDU==1 & START==0
mean AGE_MARDIS if EDU==2 & START==0
mean AGE_MARDIS if EDU==3 & START==0
kwallis AGE_MARDIS if START==0, by(EDU)

tab KIDS EDU if START==0, nof col
tab KIDS EDU if START==0, chi2

mean N_KIDS_DIV if EDU==1 & START==0 & KIDS==1
mean N_KIDS_DIV if EDU==2 & START==0 & KIDS==1
mean N_KIDS_DIV if EDU==3 & START==0 & KIDS==1
kwallis N_KIDS_DIV if START==0 & KIDS==1, by(EDU)

mean AGEYSTKID_DIV if EDU==1 & START==0 & KIDS==1
mean AGEYSTKID_DIV if EDU==2 & START==0 & KIDS==1
mean AGEYSTKID_DIV if EDU==3 & START==0 & KIDS==1
kwallis AGEYSTKID_DIV if START==0 & KIDS==1, by(EDU)

tab RES EDU if START==0 & KIDS==1, nof col
tab RES EDU if START==0 & KIDS==1, chi2

tab CUSTODY_cat EDU if START==0 & RES==1, nof col
tab CUSTODY_cat EDU if START==0 & RES==1, chi2

mean DIV_YR if EDU==1 & START==0
mean DIV_YR if EDU==2 & START==0
mean DIV_YR if EDU==3 & START==0
kwallis DIV_YR if START==0, by(EDU)

mean SEP_YR if EDU==1 & START==0 & SEP_YR!=9999
mean SEP_YR if EDU==2 & START==0 & SEP_YR!=9999
mean SEP_YR if EDU==3 & START==0 & SEP_YR!=9999
kwallis SEP_YR if START==0 & SEP_YR!=9999, by(EDU)

tab ST9 EDU if START==0, nof col

tab ROLE EDU if START==0, nof col

tab SEP EDU if START==0 & PARTK!=0, nof col

*TABLE 3
*sample composition: repartnered men

tab AGE_U EDU if START==0 & PARTK!=0, nof col
mean AGE if EDU==1 & START==0 & PARTK!=0
mean AGE if EDU==2 & START==0 & PARTK!=0
mean AGE if EDU==3 & START==0 & PARTK!=0
kwallis AGE if START==0 & PARTK!=0, by(EDU)

tab AGE_UP EDU if START==0 & PARTK!=0, nof col
mean AGE_PP if EDU==1 & START==0 & PARTK!=0 & AGE_PP!=99
mean AGE_PP if EDU==2 & START==0 & PARTK!=0  & AGE_PP!=99
mean AGE_PP if EDU==3 & START==0 & PARTK!=0  & AGE_PP!=99
kwallis AGE_PP if START==0 & PARTK!=0  & AGE_PP!=99, by(EDU)

tab PARTK EDU if START==0 & PARTK!=0, nof col
tab PARTK EDU if START==0 & PARTK!=0, chi2

tab edupart EDU if START==0 & PARTK!=0 & PART_INT==1, nof col
tab edupart EDU if START==0 & PARTK!=0 & PART_INT==1, chi2

tab EDU if PARTK!=0  & START==0  & PART_INT==1

tab PARTK CUSTODY_cat
tab RES EDU if START==0 & PARTK!=0, nof col


*FIGURE 2
*chronogram: tab time variable and sequence variable
***************************************************

*chronogram: partnership and fertility trajectories
tab START st9 if EDU==1
tab START st9 if EDU==2
tab START st9 if EDU==3

*chronogram: fatherhood roles
tab START role if EDU==1
tab START role if EDU==2
tab START role if EDU==3
 
 
*Multivariate analyses
*********************************
*TABLE 4
*1) Education-specific roles of fatherhood (multinomial logit)
mlogit ROLE ib2.EDU c.AGE_MARDIS c.DIV_YR if START==0 & ROLE!=., b(3) rrr
*mlogit ROLE ib2.EDU c.AGE_MARDIS c.DIV_YR i.NKIDS if START==0, b(1) 
outreg2 using "G:\Paper_men's postdivorce fertility\results111111.doc", /*sideway stat (coef se aster)*/ ef dec(2) replace ctitle(multinomial 1 B(SE))

	margins EDU, predict(outcome(1)) atmeans
	
	margins EDU, predict(outcome(2)) atmeans

	margins EDU, predict(outcome(3)) atmeans

	margins EDU, predict(outcome(4)) atmeans

	margins EDU, predict(outcome(5)) atmeans
	
	
	margins, predict(outcome(1)) at ((mean) AGE_MARDIS (mean) DIV_YR) dydx(EDU)
	margins, predict(outcome(2)) at ((mean) AGE_MARDIS (mean) DIV_YR) dydx(EDU)
	margins, predict(outcome(3)) at ((mean) AGE_MARDIS (mean) DIV_YR) dydx(EDU)
	margins, predict(outcome(4)) at ((mean) AGE_MARDIS (mean) DIV_YR) dydx(EDU)
	margins, predict(outcome(5)) at ((mean) AGE_MARDIS (mean) DIV_YR) dydx(EDU)				

	
*TABLE 5
****************************************************
*2a) Union formation (multinomial logit: single- childless woman  mother) 
mlogit PARTK ib2.EDU  c.AGE_MARDIS i.RES i.NoAge_Kids2 c.DIV_YR if START==0, b(0) rrr
outreg2 using "G:\Paper_men's postdivorce fertility\results3x.doc", /*sideway stat (coef se aster)*/ ef dec(2) replace ctitle(multinomial 2 B(SE))

	margins EDU RES, predict(outcome(0)) atmeans
	
	margins EDU RES, predict(outcome(1)) atmeans

	margins EDU RES, predict(outcome(2)) atmeans
	
	margins, predict(outcome(0)) at ((mean) AGE_MARDIS (mean) DIV_YR (mean) NoAge_Kids2) dydx(EDU RES)
	margins, predict(outcome(1)) at ((mean) AGE_MARDIS (mean) DIV_YR (mean) NoAge_Kids2) dydx(EDU RES)
	margins, predict(outcome(2)) at ((mean) AGE_MARDIS (mean) DIV_YR (mean) NoAge_Kids2) dydx(EDU RES)

*TABLE 6
mlogit PARTK ib2.EDU#i.RES  c.AGE_MARDIS i.NoAge_Kids2 c.DIV_YR if START==0, b(0) rrr
outreg2 using "G:\Paper_men's postdivorce fertility\results3x.doc", /*sideway stat (coef se aster)*/ ef dec(2) append ctitle(multinomial 1 B(SE))

	margins EDU#RES, predict(outcome(0)) atmeans
	marginsplot 
	margins EDU#RES, predict(outcome(1)) atmeans
	marginsplot 
	margins EDU#RES, predict(outcome(2)) atmeans
	marginsplot
	
	margins, predict(outcome(0)) at ((mean) AGE_MARDIS (mean) DIV_YR (mean) NoAge_Kids2 RES==0) dydx(EDU) 
	margins, predict(outcome(0)) at ((mean) AGE_MARDIS (mean) DIV_YR (mean) NoAge_Kids2 RES==1) dydx(EDU) 
	margins, predict(outcome(1)) at ((mean) AGE_MARDIS (mean) DIV_YR (mean) NoAge_Kids2 RES==0) dydx(EDU) 
	margins, predict(outcome(1)) at ((mean) AGE_MARDIS (mean) DIV_YR (mean) NoAge_Kids2 RES==1) dydx(EDU) 
	margins, predict(outcome(2)) at ((mean) AGE_MARDIS (mean) DIV_YR (mean) NoAge_Kids2 RES==0) dydx(EDU) 
	margins, predict(outcome(2)) at ((mean) AGE_MARDIS (mean) DIV_YR (mean) NoAge_Kids2 RES==1) dydx(EDU)
 
*TABLE 7	
*2b) for subsample of repartnered men post-divorce fertility (multinomial logit: no child, no separation  separation  common child)
logit FERT ib3.EDU  c.AGE c.AGE_PP i.RES  i.NoAge_Kids2 c.DIV_YR i.PARTK  if PARTK!=0  & START==0, or
outreg2 using "G:\Paper_men's postdivorce fertility\results333.doc", /*sideway stat (coef se aster)*/ ef dec(2) replace ctitle(multinomial 1 B(SE))

	margins EDU RES PARTK, atmeans
	margins, atmeans dydx(EDU RES PARTK)
	margins,  at ((mean)AGE (mean) AGE_PP (mean) DIV_YR (mean) NoAge_Kids2) dydx(EDU RES PARTK)

*FIGURE 3
logit FERT ib2.EDU#i.PARTK  c.AGE c.AGE_PP i.RES i.NoAge_Kids2 c.DIV_YR  if PARTK!=0  & START==0, or
outreg2 using "G:\Paper_men's postdivorce fertility\results333.doc", /*sideway stat (coef se aster)*/ ef dec(2) append ctitle(multinomial 1 B(SE))
	
	margins EDU#PARTK RES, atmeans
	marginsplot
	margins, atmeans at (PARTK==1) dydx(EDU)
	margins, at ((mean)AGE (mean) AGE_PP (mean) DIV_YR (mean) NoAge_Kids2 (mean)RES) dydx(EDU)
	margins, predict(outcome(2)) atmeans dydx(EDU RES)

*check: interaction man's education and residence with own children	
logit FERT ib2.EDU##i.RES i.PARTK  c.AGE c.AGE_PP i.NoAge_Kids2 c.DIV_YR  if PARTK!=0  & START==0, or
	margins EDU#RES, atmeans
	marginsplot

*robustness check: multinomial (incl separation)
mlogit SEP ib2.EDU ib2.AGE_U ib2.AGE_UP i.RES  i.PARTK c.DIV_YR if PARTK!=0  & START==0, b(0)
outreg2 using "E:\Paper_men's postdivorce fertility\results33.doc", /*sideway stat (coef se aster)*/ dec(2) replace ctitle(multinomial 1 B(SE))

mlogit SEP ib2.EDU#i.PARTK ib2.AGE_U ib2.AGE_UP i.RES  c.DIV_YR if PARTK!=0  & START==0, b(0)
outreg2 using "E:\Paper_men's postdivorce fertility\results33.doc", /*sideway stat (coef se aster)*/ dec(2) append ctitle(multinomial 1 B(SE))

*ROBUSTNESS CHECK: woman's education
*1) check if results stay the same for subgroup of surviving unions
*1) Education-specific roles of fatherhood (multinomial logit)
mlogit ROLE ib2.EDU c.AGE_MARDIS c.DIV_YR if START==0 & ROLE!=., b(3) rrr
	estimates store model1a
mlogit ROLE ib2.EDU c.AGE_MARDIS c.DIV_YR if START==0 & ROLE!=. & PART_INT==1, b(3) rrr
	estimates store model1b
mlogit ROLE ib2.EDU c.AGE_MARDIS c.DIV_YR ib2.edupart if START==0 & ROLE!=. & PART_INT==1, b(3) rrr
	estimates store model1c
    estimates table model1a model1b model1c

*2a) Union formation (multinomial logit: single- childless woman  mother) 
g PARTK2=PARTK-1
mlogit PARTK ib2.EDU  c.AGE_MARDIS i.RES i.NoAge_Kids c.DIV_YR if START==0, b(0)
	estimates store model2a
logit PARTK2 ib2.EDU  c.AGE_MARDIS i.RES i.NoAge_Kids c.DIV_YR if START==0 & PARTK!=0 
	estimates store model2b
logit PARTK2 ib2.EDU  c.AGE_MARDIS i.RES i.NoAge_Kids c.DIV_YR ib2.edupart if START==0 & PARTK!=0  
	estimates store model2c
	
	    estimates table model2a model2b model2c

*2b) for subsample of repartnered men post-divorce fertility (multinomial logit: no child, no separation  separation  common child)
probit FERT ib2.EDU  c.AGE c.AGE_PP i.RES i.PARTK c.DIV_YR if PARTK!=0  & START==0
	estimates store model3a
probit FERT ib2.EDU  c.AGE c.AGE_PP i.RES i.PARTK c.DIV_YR if PARTK!=0  & START==0 & PART_INT==1
	estimates store model3b
probit FERT ib2.EDU  c.AGE c.AGE_PP i.RES i.PARTK c.DIV_YR ib2.edupart if PARTK!=0  & START==0 & PART_INT==1
	estimates store model3c
	
	estimates table model3a model3b model3c
	
	logit FERT ib2.EDU#i.PARTK  c.AGE c.AGE_PP i.RES i.NoAge_Kids2 c.DIV_YR  if PARTK!=0  & START==0, or
	estimates store model4a
	outreg2 using "E:\Paper_men's postdivorce fertility\resultsrobust1.doc", /*sideway stat (coef se aster)*/ ef dec(2) replace ctitle(multinomial 1 B(SE))
	
	logit FERT ib2.EDU#i.PARTK  c.AGE c.AGE_PP i.RES i.NoAge_Kids2 c.DIV_YR  if PARTK!=0  & START==0  & PART_INT==1, or
	estimates store model4b
	outreg2 using "E:\Paper_men's postdivorce fertility\resultsrobust1.doc", /*sideway stat (coef se aster)*/ ef dec(2) append ctitle(multinomial 1 B(SE))
	
	logit FERT ib2.EDU#i.PARTK  c.AGE c.AGE_PP i.RES i.NoAge_Kids2 c.DIV_YR  ib2.edupart if PARTK!=0  & START==0  & PART_INT==1, or
	estimates store model4c
	outreg2 using "E:\Paper_men's postdivorce fertility\resultsrobust1.doc", /*sideway stat (coef se aster)*/ ef dec(2) append ctitle(multinomial 1 B(SE))
	
	estimates table model4a model4b model4c
	
	

